==> schluessel-0.3.1-src.zip: schluessel/src/net/morilib/lisp/lib/srfi014/CharSet.java <==
/*
 * Copyright 2009-2010 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.lisp.lib.srfi014;

import net.morilib.lisp.ConsIterator;
import net.morilib.lisp.Datum;
import net.morilib.lisp.Environment;
import net.morilib.lisp.LispCharacter;
import net.morilib.lisp.LispMessage;
import net.morilib.lisp.Subr;
import net.morilib.lisp.exlib.LispCharSet;
import net.morilib.util.primitive.CharacterArrayVector;
import net.morilib.util.primitive.CharacterVector;

/**
 *
 *
 * @author MORIGUCHI, Yuichiro 2011/04/09
 */
public class CharSet extends Subr {

	/* (non-Javadoc)
	 * @see net.morilib.lisp.Subr#eval(net.morilib.lisp.Datum, net.morilib.lisp.Environment, net.morilib.lisp.LispMessage)
	 */
	@Override
	public Datum eval(Datum body, Environment env, LispMessage mesg) {
		ConsIterator itr = new ConsIterator(body);
		CharacterVector v = new CharacterArrayVector();

		while(itr.hasNext()) {
			Datum d = itr.next();

			if(d instanceof LispCharacter) {
				v.addChar(d.getCharacter());
			} else {
				throw mesg.getError("err.require.char", d);
			}
		}
		return new LispCharSet(v.toCharArray());
	}

}

==> schluessel-0.4.1-src.zip: schluessel/src/net/morilib/lisp/lib/srfi014/CharSet.java <==
/*
 * Copyright 2009-2010 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.lisp.lib.srfi014;

import net.morilib.lisp.ConsIterator;
import net.morilib.lisp.Datum;
import net.morilib.lisp.Environment;
import net.morilib.lisp.LispCharacter;
import net.morilib.lisp.LispMessage;
import net.morilib.lisp.Subr;
import net.morilib.lisp.charset.LispCharSet;
import net.morilib.util.primitive.CharacterArrayVector;
import net.morilib.util.primitive.CharacterVector;

/**
 *
 *
 * @author MORIGUCHI, Yuichiro 2011/04/09
 */
public class CharSet extends Subr {

	/* (non-Javadoc)
	 * @see net.morilib.lisp.Subr#eval(net.morilib.lisp.Datum, net.morilib.lisp.Environment, net.morilib.lisp.LispMessage)
	 */
	@Override
	public Datum eval(Datum body, Environment env, LispMessage mesg) {
		ConsIterator itr = new ConsIterator(body);
		CharacterVector v = new CharacterArrayVector();

		while(itr.hasNext()) {
			Datum d = itr.next();

			if(d instanceof LispCharacter) {
				v.addChar(d.getCharacter());
			} else {
				throw mesg.getError("err.require.char", d);
			}
		}
		return new LispCharSet(v.toCharArray());
	}

}
